@@ -545,7 +545,7 @@ test -x $process_management_prog && process_entry=$(entry \
 localisation_prog=/usr/local/bin/locale-antix
 test -x $localisation_prog && localisation_entry=$(entry \
     $ICONS/preferences-desktop-locale.png \
-    "/usr/local/bin/locale-antix &" \
+    "gksu /usr/local/bin/locale-antix &" \
     $"System Language Manager" \
     $"Change Language and other locale options including downloading localised LibreOffice")
 
